@@ -1,4 +1,5 @@
 import six
+import sys
 import time
 
 from . import exceptions
@@ -65,7 +66,7 @@ class Socket(object):
     def send(self, pkt):
         """Send a packet to the client."""
         if self.closed:
-            raise IOError('Socket is closed')
+            raise exceptions.SocketIsClosedError()
         if time.time() - self.last_ping > self.server.ping_timeout:
             self.server.logger.info('%s: Client is gone, closing socket',
                                     self.sid)
@@ -91,8 +92,9 @@ class Socket(object):
         try:
             packets = self.poll()
         except exceptions.QueueEmpty:
+            exc = sys.exc_info()
             self.close(wait=False)
-            raise
+            six.reraise(*exc)
         return packets
 
     def handle_post_request(self, environ):
@@ -210,10 +212,13 @@ class Socket(object):
                 self.receive(pkt)
             except exceptions.UnknownPacketError:
                 pass
+            except exceptions.SocketIsClosedError:
+                self.server.logger.info('Receive error -- socket is closed')
+                break
             except:  # pragma: no cover
                 # if we get an unexpected exception we log the error and exit
                 # the connection properly
-                self.server.logger.exception('Receive error')
+                self.server.logger.exception('Unknown receive error')
                 break
 
         self.queue.put(None)  # unlock the writer task so that it can exit
